==> haskell-hspec-wai-0.11.1-619-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-4sbunx3MrifHVy2sHh0pK5
key:                  hspec-wai-0.11.1-4sbunx3MrifHVy2sHh0pK5
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  00d1e3c05f904a66ad22daf5a733471c
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-4sbunx3MrifHVy2sHh0pK5
depends:
    QuickCheck-2.15.0.1-K2FdhpAloErGP21S0B8fgw base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-rTys5srD4l50KQCiQKWYt
    hspec-core-2.11.3-IjEZPeANC575vr9jH9oAZe
    hspec-expectations-0.8.3-LrMpsCa55zWGlw5k4mSqLh
    http-types-0.12.4-8KsSLLTB3zVcsjL7f3kez text-2.0.2
    transformers-0.5.6.2 wai-3.2.4-IDOjyIeGcOSAX1FlCquc7y
    wai-extra-3.1.18-GcW9oQm2YP62M9iANrm1bU

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.11.1-620-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-8eF7D2P1F4OyV6WMAMT2V
key:                  hspec-wai-0.11.1-8eF7D2P1F4OyV6WMAMT2V
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  ffae7b30320af8947caf6a5220953961
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-8eF7D2P1F4OyV6WMAMT2V
depends:
    QuickCheck-2.15.0.1-1pOwhmMeliZCxioVyv9M89 base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4HYxnyEi2mnBK2ectdARDN
    hspec-core-2.11.3-AIpyqTc1kue3JLLorF2nbi
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    http-types-0.12.4-5kbj0Cv0rp8HNRwQfelhRA text-2.0.2
    transformers-0.5.6.2 wai-3.2.4-HbGzj3ODjKy9gf24pBgAvG
    wai-extra-3.1.18-EcRX4hxSfOt7Zv8HDVZhj

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
